import classes from './styles.module.scss';
import TV from '@shared/assets/images/tv.png';
import Laptop from '@shared/assets/images/laptop.png';
import { HomeButton } from './components/home.button';
import { useNavigate } from 'react-router-dom';
import { motion } from 'framer-motion';

const HomePage = () => {
  const navigation = useNavigate();

  const handleLaptopRedirect = () => {
    navigation('/laptop');
  };

  const handleTVRedirect = () => {
    navigation('/tv');
  };

  const titleVariants = {
    hidden: { y: 100, opacity: 0 },
    visible: { y: 0, opacity: 1 },
  };

  const containerVariants = {
    hidden: { y: 100, opacity: 0 },
    visible: { y: 0, opacity: 1 },
  };

  return (
    <div className={classes.home}>
      <motion.h1
        className={classes.title}
        initial="hidden"
        animate="visible"
        variants={titleVariants}
        transition={{ duration: 0.5 }}
      >
        Select the type of trained model
      </motion.h1>
      <motion.div
        className={classes.container}
        initial="hidden"
        animate="visible"
        variants={containerVariants}
        transition={{ duration: 0.5 }}
      >
        <HomeButton imgSrc={Laptop} onClick={handleLaptopRedirect} />
        <HomeButton imgSrc={TV} onClick={handleTVRedirect} />
      </motion.div>
    </div>
  );
};

export default HomePage;
