import Form from '@/widgets/form/form.widget';
import classes from './styles.module.scss';
import Laptop from '@shared/assets/images/laptop.png';
import { FormEvent, useCallback, useEffect, useState } from 'react';
import {
  LaptopCreatePredictType,
  LaptopGetDataPredictType,
  PredictResponseType,
} from '@/shared/types';
import { apiLaptop } from '@/shared/api';
import { motion } from 'framer-motion';

const LaptopPredictPage = () => {
  const [requestSelectorsData, setRequestSelectorsData] = useState<
    LaptopGetDataPredictType | undefined
  >();

  const [request, setRequest] = useState<LaptopCreatePredictType>({
    processor: '',
    ram: 0,
    os: '',
    ssd: 0,
    display_size: 0,
    resolution: '',
    matrix_type: '',
    gpu: '',
  });

  const [response, setResponse] = useState<PredictResponseType>({
    predicted_price: undefined,
  });

  const handleGetPredict = async (event: FormEvent) => {
    event.preventDefault();
    if (response.predicted_price) {
      setResponse({
        predicted_price: undefined,
      });
      return;
    }
    const newResponse = await apiLaptop.predictPrice(request);
    setResponse(newResponse);
  };

  const handleInputChange = useCallback(
    (updatedRequest: LaptopCreatePredictType) => {
      setRequest(updatedRequest);
    },
    [],
  );

  const updateField = (
    field: keyof LaptopGetDataPredictType,
    value: string | number,
  ) => {
    handleInputChange({
      ...request,
      [field]: value,
    });
    console.log(value);
  };

  useEffect(() => {
    const fetchData = async () => {
      const responseSelectorData = await apiLaptop.getDataForRequest();
      if (!responseSelectorData) {
        return;
      }
      setRequestSelectorsData(responseSelectorData);
    };

    fetchData();
  }, []);

  const iconVariants = {
    hidden: { x: -100, opacity: 0 },
    visible: { x: 0, opacity: 1 },
  };

  const containerVariants = {
    hidden: { x: 100, opacity: 0 },
    visible: { x: 0, opacity: 1 },
  };

  return (
    <div className={classes.laptop}>
      <motion.img
        src={Laptop}
        className={classes.icon}
        initial="hidden"
        animate="visible"
        variants={iconVariants}
        transition={{ duration: 0.5 }}
      />
      <motion.div
        className={classes.container}
        initial="hidden"
        animate="visible"
        variants={containerVariants}
        transition={{ duration: 0.5 }}
      >
        <Form
          selectorsData={requestSelectorsData}
          updateField={updateField}
          handleGetPredict={handleGetPredict}
          response={response}
        />
      </motion.div>
    </div>
  );
};

export default LaptopPredictPage;
