import axios from 'axios';
import {
  LaptopGetDataPredictType,
  LaptopCreatePredictType,
  PredictResponseType,
} from '../types';

class ApiLaptop {
  readonly baseURL = import.meta.env.VITE_SERVER_URL;

  getDataForRequest = async (): Promise<LaptopGetDataPredictType> => {
    try {
      const response = await axios.get<LaptopGetDataPredictType>(
        `${this.baseURL}/get_unique_data_laptop`,
      );
      return response.data;
    } catch (error) {
      console.error('Error predicting price:', error);
      throw error;
    }
  };

  predictPrice = async (
    data: LaptopCreatePredictType,
  ): Promise<PredictResponseType> => {
    try {
      const response = await axios.post<PredictResponseType>(
        `${this.baseURL}/predict_price/laptop/`,
        data,
      );
      return response.data;
    } catch (error) {
      console.error('Error predicting price:', error);
      throw error;
    }
  };
}

const apiLaptop = new ApiLaptop();
export default apiLaptop;
