import { FC, useState } from 'react';
import classes from './styles.module.scss';

type SelectorProps = {
  field: string;
  handleSetValue: (field: string, value: string) => void;
  list: string[] | number[];
};

const Selector: FC<SelectorProps> = ({ field, handleSetValue, list }) => {
  const [inputValue, setInputValue] = useState('');

  const handleChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const value = e.target.value;
    setInputValue(value);
    handleSetValue(field, value);
  };

  return (
    <select
      className={classes.selector}
      onChange={handleChange}
      value={inputValue}
    >
      <option value="" disabled>
        Select an option
      </option>
      {list.map((item, index) => (
        <option key={index} value={item}>
          {item}
        </option>
      ))}
    </select>
  );
};

export default Selector;
