import { PredictResponseType } from '@/shared/types/predict';
import { FormEvent, useMemo } from 'react';
import classes from './styles.module.scss';
import { Button } from '@/shared/components/button';
import { Selector } from '@/shared/components/selector';
import { Expander } from '@/shared/components/expander';

type FormType<T> = {
  selectorsData: T | undefined;
  updateField: (field: keyof T, value: string | number) => void;
  handleGetPredict: (e: FormEvent) => Promise<void>;
  response: PredictResponseType;
};

const Form = <T extends Record<string, string[] | number[]>>({
  selectorsData,
  updateField,
  handleGetPredict,
  response,
}: FormType<T>) => {
  const fields = selectorsData
    ? (Object.keys(selectorsData) as Array<keyof T>)
    : [];

  const buttonLabel = useMemo(
    () => (response.predicted_price ? 'Back to build' : 'Submit'),
    [response.predicted_price],
  );

  return (
    <form className={classes.form}>
      {!response.predicted_price ? (
        <div className={classes.selectorList}>
          {fields.map((field) => (
            <Expander key={field as string} title={field as string}>
              <Selector
                handleSetValue={updateField}
                list={selectorsData ? selectorsData[field] : []}
                field={field as string}
              />
            </Expander>
          ))}
        </div>
      ) : (
        <div className={classes.response}>
          <h3 className={classes.title}>Estimated price:</h3>
          <p className={classes.price}>{response.predicted_price} руб</p>
        </div>
      )}
      <div className={classes.divider} />
      <Button onClick={(e: FormEvent) => handleGetPredict(e)}>
        {buttonLabel}
      </Button>
    </form>
  );
};

export default Form;
